@@ -82,7 +82,7 @@ def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callabl
             for possible_type in type_args:
                 try:
                     return get_converter(possible_type)(value)
-                except (TypeError, ValueError):
+                except (TypeError, ValueError, AttributeError):
                     pass
             raise ValueError(f"Expected one of: {type_args}, got {type(value)}: {value}")
 
